summaryrefslogtreecommitdiff
path: root/src/gui/updatewindow.cpp
diff options
context:
space:
mode:
authorBjörn Steinbrink <B.Steinbrink@gmx.de>2005-07-27 23:22:45 +0000
committerBjörn Steinbrink <B.Steinbrink@gmx.de>2005-07-27 23:22:45 +0000
commit227aeae87bcca1ecb0183530a4cca1b038863635 (patch)
tree1f2dd29f93e904ccef0fdd9fe2c7d9778b867934 /src/gui/updatewindow.cpp
parentd15d76976b6e57a9f421ab034c6f841051b962f3 (diff)
downloadmana-client-227aeae87bcca1ecb0183530a4cca1b038863635.tar.gz
mana-client-227aeae87bcca1ecb0183530a4cca1b038863635.tar.bz2
mana-client-227aeae87bcca1ecb0183530a4cca1b038863635.tar.xz
mana-client-227aeae87bcca1ecb0183530a4cca1b038863635.zip
Added support for updates to the resource manager.
Diffstat (limited to 'src/gui/updatewindow.cpp')
-rw-r--r--src/gui/updatewindow.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/gui/updatewindow.cpp b/src/gui/updatewindow.cpp
index ebe9013f..4295b8cf 100644
--- a/src/gui/updatewindow.cpp
+++ b/src/gui/updatewindow.cpp
@@ -225,9 +225,9 @@ int UpdaterWindow::downloadThread(void *ptr)
}
else
{
- // Download in the proper folder : ./data under win,
- // /home/user/.tmw/data for unices
- outFilename = uw->mBasePath + "/data/download.temp";
+ // Download in the proper folder : ./updates under win,
+ // /home/user/.tmw/updates for unices
+ outFilename = uw->mBasePath + "/updates/download.temp";
outfile = fopen(outFilename.c_str(), "wb");
curl_easy_setopt(curl, CURLOPT_WRITEDATA, outfile);
}
@@ -256,7 +256,7 @@ int UpdaterWindow::downloadThread(void *ptr)
fclose(outfile);
// If the download was successful give the file the proper name
// else it will be deleted later
- std::string newName(uw->mBasePath + "/data/" +
+ std::string newName(uw->mBasePath + "/updates/" +
uw->mCurrentFile.c_str());
rename(outFilename.c_str(), newName.c_str());
}
@@ -374,7 +374,7 @@ void UpdaterWindow::updateData()
{
mCurrentFile = files[fileIndex];
std::ifstream temp(
- (mBasePath + "/data/" + mCurrentFile).c_str());
+ (mBasePath + "/updates/" + mCurrentFile).c_str());
if (!temp.is_open()) {
temp.close();
download();
@@ -414,7 +414,7 @@ void UpdaterWindow::updateData()
free(mMemoryBuffer);
in.close();
// Remove downloaded files
- remove((mBasePath + "/data/news.txt").c_str());
- remove((mBasePath + "/data/resources.txt").c_str());
- remove((mBasePath + "/data/download.temp").c_str());
+ remove((mBasePath + "/updates/news.txt").c_str());
+ remove((mBasePath + "/updates/resources.txt").c_str());
+ remove((mBasePath + "/updates/download.temp").c_str());
}